NAME = 'icepack'
VERSION = '0.6.1'

SECRET_KEY = 'identity'  # nosec No secret
PUBLIC_KEY = 'identity.pub'
ALLOWED_SIGNERS = 'allowed_signers'
